var IgxDetrendedPriceOscillatorIndicatorComponent_1;
import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { IgxFinancialIndicatorComponent } from "./igx-financial-indicator-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { DetrendedPriceOscillatorIndicator } from "./DetrendedPriceOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Detrended Price Oscillator indicator series.
 * Default required members: Close
*
* The `IgxDetrendedPriceOscillatorIndicatorComponent` class represents a IgxDataChartComponent Detrended Price Oscillator indicator series.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis #xAxis
*         label="label">
*     </igx-category-x-axis>
*     <igx-numeric-y-axis #yAxis>
*     </igx-numeric-y-axis>
*     <igx-detrended-price-oscillator-indicator
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         openMemberPath="open"
*         highMemberPath="high"
*         lowMemberPath="low"
*         closeMemberPath="close">
*     </igx-detrended-price-oscillator-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxDetrendedPriceOscillatorIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export const IgxDetrendedPriceOscillatorIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent) }];
let IgxDetrendedPriceOscillatorIndicatorComponent = IgxDetrendedPriceOscillatorIndicatorComponent_1 = class IgxDetrendedPriceOscillatorIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new DetrendedPriceOscillatorIndicator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the moving average period for the current DetrendedPriceOscillatorIndicator object.
     * The typical, and initial, value for DPO periods is 20.
    *
    * You can use the `period` to set the current moving average period.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis #xAxis
    *         label="label">
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-detrended-price-oscillator-indicator
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         openMemberPath="open"
    *         highMemberPath="high"
    *         lowMemberPath="low"
    *         closeMemberPath="close"
    * 		period=30>
    *     </igx-detrended-price-oscillator-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period() {
        return this.i.s5;
    }
    set period(v) {
        this.i.s5 = +v;
    }
};
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDetrendedPriceOscillatorIndicatorComponent.prototype, "period", null);
IgxDetrendedPriceOscillatorIndicatorComponent = IgxDetrendedPriceOscillatorIndicatorComponent_1 = tslib_1.__decorate([
    Component({
        selector: 'igx-detrended-price-oscillator-indicator',
        template: ``,
        providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent_1) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent_1) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent_1) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxDetrendedPriceOscillatorIndicatorComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    tslib_1.__metadata("design:paramtypes", [])
], IgxDetrendedPriceOscillatorIndicatorComponent);
export { IgxDetrendedPriceOscillatorIndicatorComponent };
//# sourceMappingURL=igx-detrended-price-oscillator-indicator-component.js.map