import * as tslib_1 from "tslib";
import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { ShapeItemSearchMode, ShapeItemSearchMode_$type } from "./ShapeItemSearchMode";
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { IgxAssigningShapeStyleEventArgs } from "./igx-assigning-shape-style-event-args";
import { IgxAssigningShapeMarkerStyleEventArgs } from "./igx-assigning-shape-marker-style-event-args";
import { IgxStyleShapeEventArgs } from "./igx-style-shape-event-args";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, ensureEnum, toPoint, fromPoint } from "igniteui-angular-core";
/**
 * Series class for rendering polygons.
*/
export const IgxShapeSeriesBaseComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxShapeSeriesBaseComponent) }];
export class IgxShapeSeriesBaseComponent extends IgxSeriesComponent {
    constructor() {
        super();
        this._assigningShapeStyle = null;
        this._assigningShapeMarkerStyle = null;
        this._styleShape = null;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
    */
    get isCustomShapeStyleAllowed() {
        return this.i.pa;
    }
    set isCustomShapeStyleAllowed(v) {
        this.i.pa = ensureBool(v);
    }
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomShapeMarkerStyleAllowed() {
        return this.i.o9;
    }
    set isCustomShapeMarkerStyleAllowed(v) {
        this.i.o9 = ensureBool(v);
    }
    get actualItemSearchMode() {
        return this.i.ou;
    }
    set actualItemSearchMode(v) {
        this.i.ou = ensureEnum(ShapeItemSearchMode_$type, v);
    }
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode() {
        return this.i.ow;
    }
    set itemSearchMode(v) {
        this.i.ow = ensureEnum(ShapeItemSearchMode_$type, v);
    }
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold() {
        return this.i.pt;
    }
    set itemSearchThreshold(v) {
        this.i.pt = +v;
    }
    /**
     * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchPointsThreshold() {
        return this.i.ps;
    }
    set itemSearchPointsThreshold(v) {
        this.i.ps = +v;
    }
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    get shapeMemberPath() {
        return this.i.p3;
    }
    set shapeMemberPath(v) {
        this.i.p3 = v;
    }
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    get xAxis() {
        if (this.i.oq == null) {
            return null;
        }
        if (!this.i.oq.externalObject) {
            let e = IgxNumericXAxisComponent._createFromInternal(this.i.oq);
            if (e) {
                e._implementation = this.i.oq;
            }
            this.i.oq.externalObject = e;
        }
        return this.i.oq.externalObject;
    }
    set xAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.oq = null : this.i.oq = v.i;
    }
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    get yAxis() {
        if (this.i.os == null) {
            return null;
        }
        if (!this.i.os.externalObject) {
            let e = IgxNumericYAxisComponent._createFromInternal(this.i.os);
            if (e) {
                e._implementation = this.i.os;
            }
            this.i.os.externalObject = e;
        }
        return this.i.os.externalObject;
    }
    set yAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.os = null : this.i.os = v.i;
    }
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    get shapeFilterResolution() {
        return this.i.pp;
    }
    set shapeFilterResolution(v) {
        this.i.pp = +v;
    }
    /**
     * Gets whether or not this series is a shape series
    */
    get isShape() {
        return this.i.dk;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.xAxis && this.xAxis.name && this.xAxis.name == name) {
            return this.xAxis;
        }
        if (this.yAxis && this.yAxis.name && this.yAxis.name == name) {
            return this.yAxis;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.xAxis && this.xAxis._styling) {
            this.xAxis._styling(container, component, this);
        }
        if (this.yAxis && this.yAxis._styling) {
            this.yAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
    getItemValue(item, memberPathName) {
        let iv = this.i.gt(item, memberPathName);
        return (iv);
    }
    getExactItemIndex(world) {
        let iv = this.i.e4(toPoint(world));
        return (iv);
    }
    getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.nt(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world) {
        let iv = this.i.gq(toPoint(world));
        return (iv);
    }
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis) {
        let iv = this.i.o5(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis) {
        let iv = this.i.o4(axis);
        return (iv);
    }
    /**
     * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
    */
    get assigningShapeStyle() {
        if (this._assigningShapeStyle == null) {
            this._assigningShapeStyle = new EventEmitter();
            this.i.assigningShapeStyle = delegateCombine(this.i.assigningShapeStyle, (o, e) => {
                let outerArgs = new IgxAssigningShapeStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningShapeStyle) {
                    this.beforeAssigningShapeStyle(this, outerArgs);
                }
                this._assigningShapeStyle.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._assigningShapeStyle;
    }
    /**
     * Event raised when Assigning Shape Marker Style
    */
    get assigningShapeMarkerStyle() {
        if (this._assigningShapeMarkerStyle == null) {
            this._assigningShapeMarkerStyle = new EventEmitter();
            this.i.assigningShapeMarkerStyle = delegateCombine(this.i.assigningShapeMarkerStyle, (o, e) => {
                let outerArgs = new IgxAssigningShapeMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningShapeMarkerStyle) {
                    this.beforeAssigningShapeMarkerStyle(this, outerArgs);
                }
                this._assigningShapeMarkerStyle.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._assigningShapeMarkerStyle;
    }
    /**
     * Raised when tile's image URI should be provided
    */
    get styleShape() {
        if (this._styleShape == null) {
            this._styleShape = new EventEmitter();
            this.i.styleShape = delegateCombine(this.i.styleShape, (o, e) => {
                let outerArgs = new IgxStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeStyleShape) {
                    this.beforeStyleShape(this, outerArgs);
                }
                this._styleShape.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._styleShape;
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxShapeSeriesBaseComponent.prototype, "isCustomShapeStyleAllowed", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxShapeSeriesBaseComponent.prototype, "isCustomShapeMarkerStyleAllowed", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "actualItemSearchMode", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "itemSearchMode", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "itemSearchThreshold", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "itemSearchPointsThreshold", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxShapeSeriesBaseComponent.prototype, "shapeMemberPath", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxNumericXAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxNumericXAxisComponent])
], IgxShapeSeriesBaseComponent.prototype, "xAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxNumericYAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxNumericYAxisComponent])
], IgxShapeSeriesBaseComponent.prototype, "yAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "shapeFilterResolution", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxShapeSeriesBaseComponent.prototype, "assigningShapeStyle", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxShapeSeriesBaseComponent.prototype, "assigningShapeMarkerStyle", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxShapeSeriesBaseComponent.prototype, "styleShape", null);
//# sourceMappingURL=igx-shape-series-base-component.js.map