import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { NumericScaleMode, NumericScaleMode_$type } from "./NumericScaleMode";
import { IgxNumericAxisBaseComponent } from "./igx-numeric-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { ensureEnum } from "igniteui-angular-core";
/**
 * Defines a set of basic methods and properties used to create a StraightNumeric axis.
*/
export const IgxStraightNumericAxisBaseComponent_PROVIDERS = [{ provide: IgxNumericAxisBaseComponent, useExisting: forwardRef(() => IgxStraightNumericAxisBaseComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxStraightNumericAxisBaseComponent) }];
export class IgxStraightNumericAxisBaseComponent extends IgxNumericAxisBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis
    *         scaleMode="logarithmic">
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    */
    get scaleMode() {
        return this.i.ll;
    }
    set scaleMode(v) {
        this.i.ll = ensureEnum(NumericScaleMode_$type, v);
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxStraightNumericAxisBaseComponent.prototype, "scaleMode", null);
//# sourceMappingURL=igx-straight-numeric-axis-base-component.js.map