import * as tslib_1 from "tslib";
import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxCategoryAngleAxisComponent } from "./igx-category-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { IgxAssigningRadialStyleEventArgs } from "./igx-assigning-radial-style-event-args";
import { IgxAssigningRadialMarkerStyleEventArgs } from "./igx-assigning-radial-marker-style-event-args";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, toPoint } from "igniteui-angular-core";
/**
 * Represents the base class for all IgxDataChartComponent radial series
*/
export var IgxRadialBaseComponent_PROVIDERS = [{ provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxRadialBaseComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxRadialBaseComponent; }) }];
var IgxRadialBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxRadialBaseComponent, _super);
    function IgxRadialBaseComponent() {
        var _this = _super.call(this) || this;
        _this._assigningRadialStyle = null;
        _this._assigningRadialMarkerStyle = null;
        return _this;
    }
    Object.defineProperty(IgxRadialBaseComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "isRadial", {
        /**
         * Checks if this series is a radial series
        */
        get: function () {
            return this.i.dh;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "isCustomRadialStyleAllowed", {
        /**
         * Gets or sets whether this Radial series should allow custom style overrides of its individual visuals.
        */
        get: function () {
            return this.i.qc;
        },
        set: function (v) {
            this.i.qc = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "isCustomRadialMarkerStyleAllowed", {
        /**
         * Gets or sets whether this Radial series should allow custom style overrides of its individual marker visuals.
        */
        get: function () {
            return this.i.qb;
        },
        set: function (v) {
            this.i.qb = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "angleAxis", {
        /**
         * Gets the effective angle axis for the current series object.
        */
        get: function () {
            if (this.i.pr == null) {
                return null;
            }
            if (!this.i.pr.externalObject) {
                var e = IgxCategoryAngleAxisComponent._createFromInternal(this.i.pr);
                if (e) {
                    e._implementation = this.i.pr;
                }
                this.i.pr.externalObject = e;
            }
            return this.i.pr.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.pr = null : this.i.pr = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "valueAxis", {
        /**
         * Gets the effective value axis for the current series object.
        */
        get: function () {
            if (this.i.py == null) {
                return null;
            }
            if (!this.i.py.externalObject) {
                var e = IgxNumericRadiusAxisComponent._createFromInternal(this.i.py);
                if (e) {
                    e._implementation = this.i.py;
                }
                this.i.py.externalObject = e;
            }
            return this.i.py.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.py = null : this.i.py = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "clipSeriesToBounds", {
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this property to true will decrease chart performance.
        */
        get: function () {
            return this.i.qa;
        },
        set: function (v) {
            this.i.qa = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxRadialBaseComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.angleAxis && this.angleAxis.name && this.angleAxis.name == name) {
            return this.angleAxis;
        }
        if (this.valueAxis && this.valueAxis.name && this.valueAxis.name == name) {
            return this.valueAxis;
        }
        return null;
    };
    IgxRadialBaseComponent.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.angleAxis && this.angleAxis._styling) {
            this.angleAxis._styling(container, component, this);
        }
        if (this.valueAxis && this.valueAxis._styling) {
            this.valueAxis._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Determine if object can be used as ValueAxis
    
    * @param axis  * The object to check
    */
    IgxRadialBaseComponent.prototype.canUseAsValueAxis = function (axis) {
        var iv = this.i.p9(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    IgxRadialBaseComponent.prototype.canUseAsAngleAxis = function (axis) {
        var iv = this.i.p8(axis);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgxRadialBaseComponent.prototype.getItem = function (world) {
        var iv = this.i.gq(toPoint(world));
        return (iv);
    };
    /**
     * Gets the angle to the provided world position from the center of the radial series.
    
    * @param world  * The world position to get the angle for
    */
    IgxRadialBaseComponent.prototype.getAngleFromWorld = function (world) {
        var iv = this.i.qh(toPoint(world));
        return (iv);
    };
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    IgxRadialBaseComponent.prototype.getExactItemIndex = function (world) {
        var iv = this.i.e4(toPoint(world));
        return (iv);
    };
    /**
     * Get the index of the item near the provided world coordinates.
    
    * @param world  * The world coordinates for which to getch the item index.
    */
    IgxRadialBaseComponent.prototype.getItemIndex = function (world) {
        var iv = this.i.f9(toPoint(world));
        return (iv);
    };
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    IgxRadialBaseComponent.prototype.scrollIntoView = function (item) {
        var iv = this.i.dq(item);
        return (iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    IgxRadialBaseComponent.prototype.getOffsetValue = function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    IgxRadialBaseComponent.prototype.getCategoryWidth = function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    Object.defineProperty(IgxRadialBaseComponent.prototype, "assigningRadialStyle", {
        /**
         * Event raised when Assigning Category Style
        */
        get: function () {
            var _this = this;
            if (this._assigningRadialStyle == null) {
                this._assigningRadialStyle = new EventEmitter();
                this.i.assigningRadialStyle = delegateCombine(this.i.assigningRadialStyle, function (o, e) {
                    var outerArgs = new IgxAssigningRadialStyleEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeAssigningRadialStyle) {
                        _this.beforeAssigningRadialStyle(_this, outerArgs);
                    }
                    _this._assigningRadialStyle.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._assigningRadialStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "assigningRadialMarkerStyle", {
        /**
         * Event raised when Assigning Radial Marker Style
        */
        get: function () {
            var _this = this;
            if (this._assigningRadialMarkerStyle == null) {
                this._assigningRadialMarkerStyle = new EventEmitter();
                this.i.assigningRadialMarkerStyle = delegateCombine(this.i.assigningRadialMarkerStyle, function (o, e) {
                    var outerArgs = new IgxAssigningRadialMarkerStyleEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeAssigningRadialMarkerStyle) {
                        _this.beforeAssigningRadialMarkerStyle(_this, outerArgs);
                    }
                    _this._assigningRadialMarkerStyle.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._assigningRadialMarkerStyle;
        },
        enumerable: true,
        configurable: true
    });
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxRadialBaseComponent.prototype, "isCustomRadialStyleAllowed", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxRadialBaseComponent.prototype, "isCustomRadialMarkerStyleAllowed", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", IgxCategoryAngleAxisComponent),
        tslib_1.__metadata("design:paramtypes", [IgxCategoryAngleAxisComponent])
    ], IgxRadialBaseComponent.prototype, "angleAxis", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", IgxNumericRadiusAxisComponent),
        tslib_1.__metadata("design:paramtypes", [IgxNumericRadiusAxisComponent])
    ], IgxRadialBaseComponent.prototype, "valueAxis", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxRadialBaseComponent.prototype, "clipSeriesToBounds", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxRadialBaseComponent.prototype, "assigningRadialStyle", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxRadialBaseComponent.prototype, "assigningRadialMarkerStyle", null);
    return IgxRadialBaseComponent;
}(IgxMarkerSeriesComponent));
export { IgxRadialBaseComponent };
//# sourceMappingURL=igx-radial-base-component.js.map