import { Type } from '@angular/core';
import { IgxSizeScaleComponent } from "./igx-size-scale-component";
import { IgxBrushScaleComponent } from "./igx-brush-scale-component";
import { IgxScatterBaseComponent } from "./igx-scatter-base-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BubbleSeries } from "./BubbleSeries";
/**
 * Represents a IgxDataChartComponent bubble series.
*/
export declare const IgxBubbleSeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxBubbleSeriesComponent extends IgxScatterBaseComponent {
    protected createImplementation(): BubbleSeries;
    /**
                                 * @hidden
                                 */
    readonly i: BubbleSeries;
    constructor();
    /**
     * Gets or sets the radius mapping property for the current series object.
    */
    radiusMemberPath: string;
    /**
     * Gets or sets the radius size scale for the bubbles.
    */
    radiusScale: IgxSizeScaleComponent;
    /**
     * Gets or sets the Label mapping property for the current series object.
    */
    labelMemberPath: string;
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    fillMemberPath: string;
    /**
     * Gets or sets the brush scale for the fill brush of markers.
    */
    fillScale: IgxBrushScaleComponent;
    /**
     * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    fillScaleUseGlobalValues: boolean;
    /**
     * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
     * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
    */
    markerOutlineUsesFillScale: boolean;
    /**
     * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
     * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
    */
    markerOutlineBrightness: number;
    /**
     * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
     * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
    */
    markerBrushBrightness: number;
    /**
     * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath from multiple series.
     * This setting applies only if multiple series are using the same RadiusScale.
    */
    radiusScaleUseGlobalValues: boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    readonly isMarkerlessDisplayPreferred: boolean;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
}
