import { Type } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { MovingAverageConvergenceDivergenceIndicator } from "./MovingAverageConvergenceDivergenceIndicator";
/**
 * Represents a IgxDataChartComponent Moving Average Convergence/Divergence (MACD) indicator series.
 * Default required members: High, Low, Close
*
* Represents a Ignite UIDataChart Moving Average Convergence/Divergence (MACD) indicator series.
*
* Example:
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
* 	<igx-moving-average-convergence-divergence-indicator
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
* 		openMemberPath="open"
*         highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close"
* 		volumeMemberPath="volume">
*     </gx-moving-average-convergence-divergence-indicatorr>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxMovingAverageConvergenceDivergenceIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath="open"
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath="close"
* series.volumeMemberPath= "volume";
* this.chart.series.add(series);
* ```
*/
export declare const IgxMovingAverageConvergenceDivergenceIndicatorComponent_PROVIDERS: ({
    provide: typeof IgxFinancialSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxMovingAverageConvergenceDivergenceIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): MovingAverageConvergenceDivergenceIndicator;
    /**
                                 * @hidden
                                 */
    readonly i: MovingAverageConvergenceDivergenceIndicator;
    constructor();
    /**
     * Gets or sets the short moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for short MACD periods is 10.
    *
    * Gets or sets the short moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-moving-average-convergence-divergence-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		shortPeriod="10">
    *     </gx-moving-average-convergence-divergence-indicatorr>
    * </igx-data-chart>
    * ```
    */
    shortPeriod: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long MACD periods is 30.
    *
    * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-moving-average-convergence-divergence-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		longPeriod="30">
    *     </gx-moving-average-convergence-divergence-indicatorr>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.longPeriod="30" ;
    * ```
    */
    longPeriod: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    *
    * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-moving-average-convergence-divergence-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		signalPeriod="30">
    *     </gx-moving-average-convergence-divergence-indicatorr>
    * </igx-data-chart>
    * ```
    */
    signalPeriod: number;
}
