import { Type } from '@angular/core';
import { IgxHorizontalRangeCategorySeriesComponent } from "./igx-horizontal-range-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { RangeAreaSeries } from "./RangeAreaSeries";
/**
 * Represents a IgxDataChartComponent range area series.
*
* The `IgxRangeAreaSeriesComponent` class represents the range area series of the IgxDataChartComponent.
*
* ```html
* <igx-data-chart
* [dataSource]="data">
* <igx-category-x-axis
* 	label="label"
* 	#xAxis>
* </igx-category-x-axis>
* <igx-numeric-y-axis
* 	#yAxis>
* </igx-numeric-y-axis>
*     <igx-range-area-series
*       [xAxis]="xAxis"
*       [yAxis]="yAxis"
*       highMemberPath="high"
*       lowMemberPath="low">
*   </igx-range-area-series>
*     </igx-data-chart>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxRangeAreaSeriesComponent = new IgxRangeAreaSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.highMemberPath = "High";
* series.lowMemberPath = "Low";
* this.chart.series.add(series);
* ```
*/
export declare const IgxRangeAreaSeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxRangeAreaSeriesComponent extends IgxHorizontalRangeCategorySeriesComponent {
    protected createImplementation(): RangeAreaSeries;
    /**
                                 * @hidden
                                 */
    readonly i: RangeAreaSeries;
    constructor();
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Use the `isAreaOrLine` property to check if the current series shows an area or line shape.
    *
    * ```ts
    * var x= series.isAreaOrLine;
    * ```
    */
    readonly isAreaOrLine: boolean;
}
