import { Type } from '@angular/core';
import { SplineType } from "./SplineType";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { SplineSeriesBase } from "./SplineSeriesBase";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export declare const IgxSplineSeriesBaseComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxSplineSeriesBaseComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    /**
                                 * @hidden
                                 */
    readonly i: SplineSeriesBase;
    constructor();
    /**
     * Gets whether the current series shows an area or line shape.
    */
    readonly isAreaOrLine: boolean;
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-spline-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         splineType="clamped"
    *         valueMemberPath="value">
    *     </igx-spline-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    */
    splineType: SplineType;
}
